require 'sale'
require 'csv'

csv_opts = {
  :col_sep => ";",
  :skip_lines => /^(Notes|The |;)/,
  :headers => true,
  :converters => :all,
}

sales = []
sales_by_date = {}

CSV.foreach(ARGV[0], csv_opts) do |row|
  if row.count > 0
    sales << SalesReporter::Sale.new(row["Date"], row["revenue EUR"], row["quantity"])
  end
end

sales.each do |s|
  d = s.date
  if sales_by_date[d]
    sales_by_date[d][:count] += s.quantity
    sales_by_date[d][:total] += s.amount
  else
    sales_by_date[d] = {:count => s.quantity, :total => s.amount}
  end
end

puts "Date:       Streams:  Revenue:"
puts "------------------------------------------"

total_rev = 0
total_streams = 0

sales_by_date.each do |key, row|
  puts "#{key.iso8601}: #{row[:count].to_s.rjust(7)} #{row[:total].round(5).to_s.rjust(10)} EUR"
  total_rev += row[:total]
  total_streams += row[:count]
end

puts "------------------------------------------"
puts "Total:      #{total_streams.to_s.rjust(7)} #{total_rev.round(5).to_s.rjust(10)} EUR"
